@@ -1,2 +1,2 @@
-from .http import SeleniumRequestBrowserUc
+from .http import SeleniumBrowserUcRequest
 from .middlewares import SeleniumBrowserUcMiddleware
