@@ -1,7 +1,7 @@
 from scrapy import Request
 
 
-class SeleniumRequestBrowserUc(Request):
+class SeleniumBrowserUcRequest(Request):
     def __init__(self, wait_time=None, wait_until=None, screenshot=False, script=None, *args, **kwargs):
         self.wait_time = wait_time
         self.wait_until = wait_until
