@@ -8,6 +8,7 @@ from scrapy.http import HtmlResponse
 # from uc_browser.browser_v2 import BrowserV2
 import undetected_chromedriver as uc
 
+
 from selenium.webdriver import Chrome
 from selenium.webdriver import ChromeOptions
 from selenium.common.exceptions import TimeoutException, WebDriverException
@@ -15,7 +16,7 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 
-from .http import SeleniumRequestBrowserUc
+from .http import SeleniumBrowserUcRequest
 
 
 class SeleniumBrowserUcMiddleware:
@@ -37,7 +38,7 @@ class SeleniumBrowserUcMiddleware:
         return middleware
 
     def process_request(self, request, spider):
-        if not isinstance(request, SeleniumRequestBrowserUc):
+        if not isinstance(request, SeleniumBrowserUcRequest):
             return None
         self.driver.get(request.url)
 
